@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 by Barry A. Warsaw
+# Copyright (C) 2009-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -14,9 +14,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with flufl.i18n.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Module contents."""
+"""Catalog search strategies."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
