@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 by Barry A. Warsaw
+# Copyright (C) 2009-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -16,7 +16,7 @@
 
 """Substitutions."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
