@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 by Barry A. Warsaw
+# Copyright (C) 2009-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -16,7 +16,7 @@
 
 """Basic translation context class."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
@@ -30,6 +30,12 @@ import textwrap
 from flufl.i18n._substitute import attrdict, Template
 from flufl.i18n._expand import expand
 
+try:
+    unicode_type = unicode
+except NameError:
+    # Python 3
+    unicode_type = str
+
 
 
 class Translator:
@@ -48,6 +54,12 @@ class Translator:
         self._catalog = catalog
         self.dedent = dedent
         self.depth = depth
+        # Python 3's .gettext() returns unicodes.
+        try:
+            self._gettext = self._catalog.ugettext
+        except AttributeError:
+            # Must be Python 3, right?
+            self._gettext = self._catalog.gettext
 
     def translate(self, original, extras=None):
         """Translate the string.
@@ -71,7 +83,7 @@ class Translator:
         # constraint, make sure that all strings to come out of this are
         # unicodes, even if the translated string or dictionary values are
         # 8-bit strings.
-        tns = self._catalog.ugettext(original)
+        tns = self._gettext(original)
         charset = self._catalog.charset() or 'us-ascii'
         # Do PEP 292 style $-string interpolation into the resulting string.
         #
@@ -91,15 +103,15 @@ class Translator:
         raw_dict.update(frame.f_locals)
         if extras is not None:
             raw_dict.update(extras)
-        # Python requires ** dictionaries to have str, not unicode keys.  For
-        # our purposes, keys should always be ascii.  Values though should be
-        # unicode.
+        # Python 2 requires ** dictionaries to have str, not unicode keys.
+        # For our purposes, keys should always be ascii.  Values though should
+        # be unicode.
         translated_string = expand(tns, attrdict(raw_dict), Template)
         # Use the bytes type here instead of str for better compatibility with
         # 2to3, which transforms this code into trying to decode a unicode to
         # a unicode.
         if isinstance(translated_string, bytes):
-            translated_string = unicode(translated_string, charset)
+            translated_string = unicode_type(translated_string, charset)
         # Dedent the string if so desired.
         if self.dedent:
             translated_string = textwrap.dedent(translated_string)
