@@ -1,4 +1,4 @@
-# Copyright (C) 2009, 2010 by Barry A. Warsaw
+# Copyright (C) 2009-2012 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -21,7 +21,7 @@ does not play well with the way doctest executes Python code.  But see
 translator.txt for a description of how this should work in real Python code.
 """
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
